"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GenericParser = void 0;
var saxophone_ts_1 = require("saxophone-ts");
var Tag = /** @class */ (function () {
    function Tag(tag) {
        if (tag) {
            this.update(tag);
        }
    }
    Tag.prototype.update = function (tag) {
        this.name = tag.name;
        if (tag.attrs)
            this.attrs = saxophone_ts_1.parseAttrs(tag.attrs);
    };
    return Tag;
}());
var GenericParser = /** @class */ (function () {
    function GenericParser(xml) {
        this.xml = xml;
        this.parser = new saxophone_ts_1.Saxophone();
    }
    GenericParser.prototype.parse = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var currentTag;
            _this.parser.on('tagOpen', function (pTag) {
                var newTag = new Tag(pTag);
                if (currentTag) {
                    if (!currentTag.next) {
                        currentTag.next = [];
                    }
                    currentTag.next.push(newTag);
                    newTag.previous = currentTag;
                }
                currentTag = newTag;
            });
            _this.parser.on('text', function (pText) {
                if (pText.contents.trim().indexOf('\n') === -1) {
                    currentTag.text = pText.contents.trim();
                }
            });
            _this.parser.on('tagClose', function (pTag) {
                if (currentTag.previous) {
                    currentTag = currentTag.previous;
                }
            });
            _this.parser.on('finish', function () {
                resolve(currentTag);
            });
            _this.parser.on('error', function (err) {
                reject(err);
            });
            _this.parser.parse(_this.xml);
        });
    };
    return GenericParser;
}());
exports.GenericParser = GenericParser;
